# <font style="background-color:#74B602;"> </font> 接口信息
| **<font style="color:black;">RequestType</font>** | **<font style="color:#0070c0;">6004 </font>**<font style="color:#8A8F8D;">发货前  </font>**<font style="color:#0070c0;">/  6006</font>**<font style="color:#8A8F8D;">发货后</font>**<font style="color:#0070c0;">/  6016 </font>**<font style="color:#8A8F8D;">发货后</font> |
| --- | --- |
| **<font style="color:black;">批量请求</font>** | 不支持批量，可并发 |
| **<font style="color:#0070c0;">6004/6006</font>****计费方式** | 按照请求成功次数计费，请求失败不计费 |
| **<font style="color:#0070c0;">6016 </font>****计费方式** | 40个自然日内1个物流编码+1个单号不限查询次数，订阅成功即计算使用1单 |
| **<font style="color:black;">接口地址</font>** | https://api.kdniao.com/api/dist |


_💡__<font style="color:#585A5A;">如果您第一次使用快递鸟，请参考</font>_[_**<font style="color:#117CEE;">接口规范</font>**_](https://www.yuque.com/kdnjishuzhichi/dfcrg1/zes04h)

# <font style="background-color:#74B602;"> </font><font style="color:#117CEE;"> </font>**场景**
:::info
### 发货前调用
买家浏览商品-下单前，根据<font style="color:#AD1A2B;">买家默认地址--商家发货地址</font>计算预计到达时间，减少沟通成本

:::



:::info
### 发货后调用
在轨迹信息更新中**<font style="color:#AD1A2B;">动态显示</font>**预计送达时间，减少买家信息差，提升服务体验

**<font style="color:#2F8EF4;">注意：历史/已签收单号请勿通过此接口请求</font>**

:::





# <font style="background-color:#74B602;"> </font><font style="color:#117CEE;"> </font>发货前
## <font style="color:#AD1A2B;background-color:rgba(80,104,242,1);"> </font> 请求示例
```json
{
"ShipperCode":"YD",
"CatchTime":"2023-07-10 20:18:57",
"ReceiveArea":"番禺区",
"ReceiveCity":"广州市",
"ReceiveProvince":"广东省",
"SendArea":"福田区",
"SendCity":"深圳市",
"SendProvince":"广东省"
}
```

### <font style="background-color:#117CEE;"> </font> 应用级参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | :---: | --- |
| ShipperCode | <font style="color:#595959;">String(10)</font> | - [x]  | [快递公司编码](#j8nli) |
| <font style="color:#000000;">SendProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发省 |
| <font style="color:#000000;">SendCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发市 |
| <font style="color:#000000;">SendArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发区县 |
| <font style="color:#000000;">SendAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发详细地址 |
| <font style="color:#000000;">ReceiveProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的省</font> |
| <font style="color:#000000;">ReceiveCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的市</font> |
| <font style="color:#393939;">ReceiveArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的区县</font> |
| <font style="color:#393939;">ReceiveAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | <font style="color:#000000;">目的详细地址</font> |
| <font style="color:#000000;">CatchTime</font> | <font style="color:#595959;">LocalDataTime</font> | - [ ]  | 揽收时间<br/><font style="color:#585A5A;">如不传，默认当前时间为揽收时间</font> |


 

## <font style="background-color:rgba(80,104,242,1);"> </font> 返回参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | :---: | --- |
| ShipperCode | <font style="color:#595959;">String(10)</font> | - [x]  | [快递公司编码](#j8nli) |
| <font style="color:#000000;">SendProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发省 |
| <font style="color:#000000;">SendCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发市 |
| <font style="color:#000000;">SendArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发区县 |
| <font style="color:#000000;">SendAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发详细地址 |
| <font style="color:#000000;">ReceiveProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的省</font> |
| <font style="color:#000000;">ReceiveCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的市</font> |
| <font style="color:#393939;">ReceiveArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的区县</font> |
| <font style="color:#393939;">ReceiveAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | <font style="color:#000000;">目的详细地址</font> |
| <font style="color:#000000;">DeliveryTime</font> | <font style="color:#595959;">String</font> | - [x]  | 预计送达时间<br/>示例：`"06月15日下午可达"` |
| <font style="color:#000000;">DeliveryDate</font> | <font style="color:#595959;">String</font> | - [x]  | <font style="color:#333333;">xxxx-xx-xx格式日期</font><br/><font style="color:#333333;">示例：</font>`<font style="color:#333333;">2024-04-20</font>` |
| <font style="color:#393939;">Hour</font> | <font style="color:#595959;">String</font> | - [x]  | <font style="color:#393939;">预计时效</font><br/>示例：`"36h"` |
| <font style="color:#393939;">PredictPath</font> | <font style="color:#595959;">String</font> | - [ ]  | <font style="color:#393939;">预估行驶线路</font><br/>示例：`"<font style="color:#393939;">深圳观澜事业部->深圳转运中心->广州转运中心->广州白云投揽部</font>"` |


<details class="lake-collapse"><summary id="u502e8b9c"><span class="ne-text" style="color: #000000; font-size: 16px">DeliveryTime</span><span class="ne-text" style="font-size: 16px">预计送达时间计算方式</span></summary><ol class="ne-ol"><li id="ud536a57f" data-lake-index-type="0"><span class="ne-text" style="font-size: 16px">有</span><span class="ne-text" style="color: #393939; font-size: 16px">传入揽收时间：</span><span class="ne-text" style="color: #000000; font-size: 16px">DeliveryTime</span><span class="ne-text" style="color: #393939; font-size: 16px">=揽收时间+预计时效</span></li><li id="ue0c72761" data-lake-index-type="0"><span class="ne-text" style="color: #393939; font-size: 16px">没有传入揽收时间：</span><span class="ne-text" style="color: #000000; font-size: 16px">DeliveryTime</span><span class="ne-text" style="color: #393939; font-size: 16px">=当前时间+预计时效</span></li><li id="uae07065f" data-lake-index-type="0"><span class="ne-text" style="color: #393939; font-size: 16px">0~12小时上午可达；12~24小时下午可达</span></li></ol></details>


### <font style="background-color:#117CEE;"> </font> 返回示例
```json
{
	"CatchTime": "2023-06-13 16:18:57",
	"ReceiveArea": "芙蓉区",
	"ReceiveCity": "长沙市",
	"ReceiveProvince": "湖南省",
	"SendArea": "白云区",
	"SendCity": "广州市",
	"SendProvince": "广东省",
	"ShipperCode": "DBL"
}
```

```json
{
  "EBusinessID" : "1000000",
  "Data" : {
    "DeliveryTime" : "06月15日下午可达",
    "SendAddress" : null,
    "ReceiveArea" : "芙蓉区",
    "SendProvince" : "广东省",
    "ReceiveProvince" : "湖南省",
    "ShipperCode" : "DBL",
    "Hour" : "52h",
    "SendArea" : "白云区",
    "ReceiveAddress" : null,
    "SendCity" : "广州市",
    "ReceiveCity" : "长沙市"
  },
  "ResultCode" : "100",
  "Success" : true
}
```





---

# <font style="background-color:#74B602;"> </font><font style="color:#117CEE;"> </font>发货后
## <font style="color:#AD1A2B;background-color:rgba(80,104,242,1);"> </font> 请求示例
```json
{
"ShipperCode":"YD",
"LogisticCode":"312262132075882",
"CatchTime":"2024-01-05 12:07:40",
"ReceiveArea":"广宗县",
"ReceiveCity":"邢台市",
"ReceiveProvince":"河北省",
"SendArea":"汉阳区",
"SendCity":"武汉市",
"SendProvince":"湖北省"
}
```

### <font style="background-color:#117CEE;"> </font> 应用级参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | :---: | --- |
| ShipperCode | <font style="color:#595959;">String(10)</font> | - [x]  | [快递公司编码](#j8nli) |
| <font style="color:#000000;">LogisticCode</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 快递单号 |
| <font style="color:#000000;">SendProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发省 |
| <font style="color:#000000;">SendCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发市 |
| <font style="color:#000000;">SendArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 始发区县 |
| <font style="color:#000000;">SendAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发详细地址 |
| <font style="color:#000000;">ReceiveProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的省</font> |
| <font style="color:#000000;">ReceiveCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的市</font> |
| <font style="color:#393939;">ReceiveArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的区县</font> |
| <font style="color:#393939;">ReceiveAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | <font style="color:#000000;">目的详细地址</font> |
| <font style="color:#000000;">SenderPhone</font> | <font style="color:#595959;">String(20)</font> | <font style="background:#F8CED3;color:#70000D">顺丰必填</font><br/><font style="background:#C0DDFC;color:#00346B">中通必填</font><br/><font style="color:#AD1A2B;">二选一</font> | <font style="color:#000000;">寄件人后四位手机尾号</font> |
| <font style="color:#000000;">ReceivePhone</font> | <font style="color:#595959;">String(20)</font> | | <font style="color:#000000;">收件人后四位手机尾号</font> |
| <font style="color:#000000;">CatchTime</font> | <font style="color:#595959;">LocalDataTime</font> | - [ ]  | 揽收时间<br/><font style="color:#585A5A;">如不传，默认当前时间为揽收时间</font> |


 

## <font style="background-color:rgba(80,104,242,1);"> </font> 返回参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- |
| ShipperCode | <font style="color:#595959;">String(10)</font> | - [x]  | [快递公司编码](#j8nli) |
| <font style="color:#000000;">LogisticCode</font> | <font style="color:#595959;">String(20)</font> | - [x]  | 快递单号 |
| <font style="color:#000000;">SendProvince</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发省 |
| <font style="color:#000000;">SendCity</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发市 |
| <font style="color:#000000;">SendArea</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发区县 |
| <font style="color:#000000;">SendAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | 始发详细地址 |
| <font style="color:#000000;">ReceiveProvince</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的省</font> |
| <font style="color:#000000;">ReceiveCity</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的市</font> |
| <font style="color:#393939;">ReceiveArea</font> | <font style="color:#595959;">String(20)</font> | - [x]  | <font style="color:#000000;">目的区县</font> |
| <font style="color:#393939;">ReceiveAddress</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | <font style="color:#000000;">目的详细地址</font> |
| <font style="color:#333333;">LatestStation</font> | <font style="color:#595959;">String(20)</font> | - [ ]  | <font style="color:#333333;">最新轨迹发生的站点</font><br/><font style="color:#8A8F8D;">若无轨迹，返回内容为null</font> |
| <font style="color:#333333;">LatestProvince</font> | <font style="color:#595959;">String(20)</font> |  | <font style="color:#333333;">最新所在省份 </font><font style="color:#8A8F8D;">若无轨迹，返回内容为null</font> |
| <font style="color:#333333;">LatestCity</font> | <font style="color:#595959;">String(20)</font> | | <font style="color:#333333;">最新所在城市 </font><font style="color:#8A8F8D;">若无轨迹，返回内容为null</font> |
| <font style="color:#333333;">LatestArea</font> | <font style="color:#595959;">String(20)</font> | | <font style="color:#333333;">最新所在区县 </font><font style="color:#8A8F8D;">若无轨迹，返回内容为null</font> |
| <font style="color:#000000;">DeliveryTime</font> | <font style="color:#595959;">String</font> | - [x]  | 预计送达时间<br/>示例：`"06月15日下午可达"` |
| <font style="color:#000000;">DeliveryDate</font> | <font style="color:#595959;">String</font> | - [x]  | <font style="color:#333333;">xxxx-xx-xx格式日期</font><br/><font style="color:#333333;">示例：</font>`<font style="color:#333333;">2024-04-20</font>` |
| <font style="color:#393939;">Hour</font> | <font style="color:#595959;">String</font> | - [x]  | <font style="color:#393939;">预计时效</font><br/>示例：`"36h"` |
| <font style="color:#393939;">PredictPath</font> | <font style="color:#595959;">String</font> | - [ ]  | <font style="color:#393939;">预估行驶线路</font><br/>示例：`"<font style="color:#393939;">深圳观澜事业部->深圳转运中心->广州转运中心->广州白云投揽部</font>"` |
| <font style="color:#393939;"> DeliveryMemo  </font> | <font style="color:#595959;">String</font> | - [ ]  | <font style="color:#393939;">备注</font><br/><font style="color:#393939;">示例：预测发起时间：2024-08-21 14:39:03</font> |






# 地址入参标准
💡不规则的省市区名称会导致识别错误，请严格按照各省市区标准名称传入

[省市区传参标准.xlsx](https://www.yuque.com/attachments/yuque/0/2024/xlsx/32723986/1704447163773-4c7fb607-8ac2-49a4-ad89-e339aba5c409.xlsx)

> 数据来源：[国家统计局https://www.stats.gov.cn/sj/tjbz/tjyqhdmhcxhfdm/2023/index.html](https://www.stats.gov.cn/sj/tjbz/tjyqhdmhcxhfdm/2023/index.html)
>

